sequencetools.yield_all_permutations_of_sequence_in_orbit
=========================================================

.. autofunction:: abjad.tools.sequencetools.yield_all_permutations_of_sequence_in_orbit.yield_all_permutations_of_sequence_in_orbit
